aboutsummaryrefslogtreecommitdiffstats
path: root/OpenAL32/Include/alMain.h
diff options
context:
space:
mode:
Diffstat (limited to 'OpenAL32/Include/alMain.h')
-rw-r--r--OpenAL32/Include/alMain.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/OpenAL32/Include/alMain.h b/OpenAL32/Include/alMain.h
index 9b1bcca9..aad409dc 100644
--- a/OpenAL32/Include/alMain.h
+++ b/OpenAL32/Include/alMain.h
@@ -361,9 +361,8 @@ struct ALCdevice_struct
// Map of Effects for this device
UIntMap EffectMap;
- // Linked List of Filters for this device
- struct ALfilter *FilterList;
- ALuint FilterCount;
+ // Map of Filters for this device
+ UIntMap FilterMap;
// Linked List of Databuffers for this device
struct ALdatabuffer *DatabufferList;